# flake8: noqa: PYI021
def unified_diff(text1, text2):
    """
    Compares two multiline strings and returns the difference in the
    standard unified diff format. This is a high-performance implementation
    written in Rust.
    """
